"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _webpackSources = require("webpack-sources");

var _util = require("./util");

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * Webpack File Preprocessor Plugin.
 */
var WebpackFilePreprocessorPlugin =
/*#__PURE__*/
function () {
  /**
   * Creates an instance of WebpackFilePreprocessorPlugin.
   *
   * @param {*} options
   */
  function WebpackFilePreprocessorPlugin(options) {
    _classCallCheck(this, WebpackFilePreprocessorPlugin);

    this.options = Object.assign({
      debug: false
    }, options);
  }
  /**
   * Apply the plugin during compilation.
   *
   * @param {*} compiler
   */


  _createClass(WebpackFilePreprocessorPlugin, [{
    key: "apply",
    value: function apply(compiler) {
      var options = this.options;

      if (!(0, _util.validateOptions)(options)) {
        console.warn('WARNING WebpackFilePreprocessorPlugin instantiated with invalid options.');
        return;
      }

      compiler.plugin('emit', function (compilation, callback) {
        if (options.debug === true) {
          process.stdout.write('Preprocessing Assets:\n');
        } // Loop through the compilation assets


        (0, _util.forEach)(compilation.assets, function (asset, filename) {
          if (!options.pattern.test(filename)) {
            return;
          }

          var processed = options.process(asset.source(), filename); // Trigger the process callback

          var size = asset.size();
          var processedSize = processed.length;
          var ratio = Number(100 - processedSize * 100 / size).toPrecision(3);

          if (options.debug === true) {
            process.stdout.write(" - ".concat(filename, " \t\t").concat(size, "B -> ").concat(processedSize, "B\t\t[").concat(ratio, " %]\n"));
          } // Replace the source file with minified html


          compilation.assets[filename] = new _webpackSources.RawSource(processed);
        });

        if (options.debug === true) {
          process.stdout.write('\n');
        }

        callback();
      });
    }
  }]);

  return WebpackFilePreprocessorPlugin;
}();

var _default = WebpackFilePreprocessorPlugin;
exports["default"] = _default;