"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.validateOptions = validateOptions;
exports.forEach = forEach;

/**
 * Check if the value is a valid RegExp.
 *
 * @param {*} value
 * @returns {boolean}
 */
function isValidRegExp(value) {
  return value instanceof RegExp;
}
/**
 * Check if the value is a function.
 *
 * @param {*} value
 * @returns {boolean}
 */


function isFunction(value) {
  return typeof value === 'function';
}
/**
 * Validate plugin options.
 *
 * @param {*} options
 * @returns {boolean}
 */


function validateOptions(options) {
  var pattern = options.pattern,
      process = options.process;
  return isValidRegExp(pattern) && isFunction(process);
}
/**
 * Loop through each key of an object.
 *
 * @param {*} object
 * @param {Function} callback
 */


function forEach(object, callback) {
  for (var key in object) {
    if (!Object.prototype.hasOwnProperty.call(object, key)) {
      continue;
    }

    callback(object[key], key);
  }
}